@@ -18,8 +18,6 @@
 
 
 
-static GdkPixbuf * get_missing (GtkIconTheme *icon_theme,
-				int           preffered_size);
 static void button_widget_icon_theme_changed (ButtonWidget *button);
 static void button_widget_reload_pixbuf (ButtonWidget *button);
 
@@ -192,36 +190,14 @@ button_widget_reload_pixbuf (ButtonWidget *button)
 						  button->orientation & PANEL_VERTICAL_MASK   ? button->size : -1,
 						  button->orientation & PANEL_HORIZONTAL_MASK ? button->size : -1,
 						  &error);
-		if (error && button->no_icon_dialog == NULL) {
-			button->no_icon_dialog = panel_error_dialog (
-					NULL, gdk_screen_get_default (),
-					"cannot_load_pixbuf", TRUE,
-					_("Could not load icon"), error);
+		if (error) {
+			button->pixbuf = gtk_widget_render_icon (GTK_WIDGET (button),
+								 GTK_STOCK_MISSING_IMAGE,
+								 (GtkIconSize) -1, NULL);
 			g_free (error);
-
-			g_signal_connect (button->no_icon_dialog, "destroy",
-					  G_CALLBACK (gtk_widget_destroyed),
-					  &button->no_icon_dialog);
-
-			g_signal_connect_swapped (button, "destroy",
-						  G_CALLBACK (gtk_widget_destroy),
-						  button->no_icon_dialog);
-		} else if (error) {
-			gtk_window_set_screen (GTK_WINDOW (button->no_icon_dialog),
-					       gtk_widget_get_screen (GTK_WIDGET (button)));
-			gtk_window_present (GTK_WINDOW (button->no_icon_dialog));
 		}
 	}
 
-	if (button->pixbuf == NULL)
-		button->pixbuf = get_missing (button->icon_theme,
-					      button->size);
-	else if (button->no_icon_dialog != NULL)
-		gtk_widget_destroy (button->no_icon_dialog);
-
-	if (button->pixbuf == NULL)
-		return;
-
 	button->pixbuf_hc = make_hc_pixbuf (button->pixbuf);
 
 	gtk_widget_queue_resize (GTK_WIDGET (button));
@@ -315,20 +291,6 @@ button_widget_set_property (GObject      *object,
 	}
 }
 
-static GdkPixbuf *
-get_missing (GtkIconTheme *icon_theme,
-	     int           preffered_size)
-{
-	GdkPixbuf *retval = NULL;
-
-	retval = gtk_icon_theme_load_icon (icon_theme, "gnome-unknown",
-					   preffered_size, 0, NULL);
-	if (retval == NULL)
-		retval = missing_pixbuf (preffered_size);
-
-	return retval;
-}
-
 static GtkArrowType
 calc_arrow (PanelOrientation  orientation,
 	    int               button_width,
@@ -518,7 +480,14 @@ button_widget_size_allocate (GtkWidget     *widget,
 	else
 		size = allocation->width;
 
-	size = CLAMP (size, 1, 48);
+	if (size < 22)
+		size = 16;
+	else if (size < 32)
+		size = 22;
+	else if (size < 48)
+		size = 32;
+	else
+		size = 48;
 
 	if (button_widget->size != size) {
 		button_widget->size = size;
@@ -608,8 +577,6 @@ button_widget_instance_init (ButtonWidget *button)
 	button->orientation = PANEL_ORIENTATION_TOP;
 
 	button->size = 0;
-
-	button->no_icon_dialog = NULL;
 	
 	button->activatable   = FALSE;
 	button->ignore_leave  = FALSE;
