@@ -524,12 +524,16 @@ panel_widget_reset_focus (GtkContainer *container,
 	PanelWidget *panel = PANEL_WIDGET (container);
 
 	if (container->focus_child == widget) {
-		GList *l;
+		GList *children;
+
+		children = gtk_container_get_children (container);
+
+		/* More than one element on the list */
+		if (children && children->next) {
+			GList *l;
 
-		l = gtk_container_get_children (container);
-		if (l && l->next) { /* More than one element on the list */
 			/* There are still object on the panel */
-			for (; l; l = l->next) {
+			for (l = children; l; l = l->next) {
 				GtkWidget *child_widget;
 
 				child_widget = l->data;
@@ -550,7 +554,7 @@ panel_widget_reset_focus (GtkContainer *container,
 		} else
 			panel_widget_focus (panel);
 
-		g_list_free (l);
+		g_list_free (children);
 	}
 }
 
@@ -1322,6 +1326,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	GList *list;
 	int i;
 	int old_size;
+	gboolean ltr;
 
 	g_return_if_fail(PANEL_IS_WIDGET(widget));
 	g_return_if_fail(allocation!=NULL);
@@ -1329,6 +1334,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 	panel = PANEL_WIDGET(widget);
 
 	old_size = panel->size;
+	ltr = gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR;
 	
 	widget->allocation = *allocation;
 	if (GTK_WIDGET_REALIZED (widget))
@@ -1391,7 +1397,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 				}
 
 				ad->cells = challoc.width;
-				challoc.x = ad->constrained;
+				challoc.x = ltr ? ad->constrained : panel->size - ad->constrained - challoc.width;
 				challoc.y = allocation->height / 2 - challoc.height / 2;
 			} else {
 				if (ad->expand_minor)
@@ -1499,7 +1505,7 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 				if (ad->expand_minor) {
 					challoc.height = allocation->height;
 				}
-				challoc.x = ad->constrained;
+				challoc.x = ltr ? ad->constrained : panel->size - ad->constrained - challoc.width;
 				challoc.y = allocation->height / 2 - challoc.height / 2;
 			} else {
 				challoc.height = ad->cells;
@@ -1863,17 +1869,22 @@ panel_widget_applet_drag_end (PanelWidget *panel)
 	gdk_flush ();
 }
 
-/*get pos of the cursor location*/
+/*get pos of the cursor location in panel coordinates*/
 int
 panel_widget_get_cursorloc (PanelWidget *panel)
 {
 	int x, y;
+	gboolean rtl;
 
 	g_return_val_if_fail (PANEL_IS_WIDGET (panel), -1);
 
 	gtk_widget_get_pointer (GTK_WIDGET (panel), &x, &y);
-
-	return panel->orient == GTK_ORIENTATION_HORIZONTAL ? x : y;
+	rtl = gtk_widget_get_direction (GTK_WIDGET (panel)) == GTK_TEXT_DIR_RTL;
+	
+	if (panel->orient == GTK_ORIENTATION_HORIZONTAL)
+		return (rtl ? panel->size - x : x);
+	else
+		return y;
 }
 
 /*calculates the value to move the applet by*/
@@ -2192,7 +2203,10 @@ panel_widget_applet_button_press_event (GtkWidget      *widget,
 		return TRUE;
 	}
 
-	if (panel_lockdown_get_locked_down () || event->button != 2)
+	/* Begin drag if the middle mouse button is pressed, unless the panel
+	 * is locked down or a grab is active (meaning a menu is open) */
+	if (panel_lockdown_get_locked_down () || event->button != 2 ||
+	    gtk_grab_get_current() != NULL)
 		return FALSE;
 
 	/* time on sent events seems to be bogus */
